@@ -44,7 +44,7 @@ def doi(isbn):
 
 
 def ren(fp):
-    """Renames a file using metadata from an ISBN in his filename."""
+    """Rename a file using metadata from an ISBN in his filename."""
     cfp = File(fp)
     isbn = EAN13(cfp.name)
     if not isbn:                               # pragma: no cover
